/**
 * Adds a "Don't sync this" menu item to the toolbox context menu. Unsynced
 * toolbox items are moved into a special "unsynced" folder that is not
 * picked up by Komodo Sync.
 */
let ToolboxSyncController = {
    _engine: null,
    get engine() {
        if (!this._engine) {
            try {
                this._engine = Weave.Engines.get('tools');
            } catch(e) {
                // Weave is not loaded, fail silently.
            }
        }
        return this._engine;
    },
    
    onLoad: function() {
        window.controllers.appendController(this);
    },
    
    supportsCommand: function(cmd) {
        return cmd === 'Sync:IgnoreTool';
    },
    
    isCommandEnabled: function(cmd) {
        var view = ko.views.manager && ko.views.manager.currentView;
        switch (cmd) {
            case "Sync:IgnoreTool":
                if (!this.engine) {
                    // Tools engine hasn't been registered
                    return false;
                } else {
                    let files = this.getCurrentToolFiles();
                    if (files.length == 0)
                        return false;
                    let disabled = false;
                    for each (let file in files) {
                        disabled |=
                            (file.path == this.engine.unsyncedFolder.path);
                        disabled |=
                            this.engine.unsyncedFolder.contains(file, true);
                        if (disabled)
                            break;
                    }
                    return !disabled;
                }
        }
        return false;
    },
    
    getCurrentToolFiles: function ToolboxSyncUtils_getCurrentToolFiles() {
        var view = ko.toolbox2.manager.view;
        var files = []
        if (view && view.selection.count >= 1) {
            let indices = ko.toolbox2.getSelectedIndices();
            for each (let index in indices) {
                let path = view.getPathFromIndex(index);
                let file = Components.classes["@mozilla.org/file/local;1"].
                         createInstance(Components.interfaces.nsILocalFile);
                file.initWithPath(path);
                files.push(file);
            }
        }
        return files;
    },

    ignoreCurrentTools: function ToolboxSyncUtils_ignoreCurrentTools() {
        var selection = ko.toolbox2.manager.view.selection;
        var files = this.getCurrentToolFiles();
        var prefName = "ignore_tool_sync";
        var fullPrefName = "donotask_" + prefName;
        var ignore = "OK";
        if (gPrefSvc) {
            let prefs = gPrefSvc.prefs;
            if (!prefs.hasBooleanPref(fullPrefName))
                prefs.setBooleanPref(fullPrefName, false);
            let count = selection.count;
            let items = (count == 1) ? count + " item " : count + " items ";
            let query = "This will move " + items + " into a special " +
                        "\"unsynced\" folder that will be ignored by " +
                        "Komodo Sync.";
            ignore = ko.dialogs.okCancel(query, null, null, "Komodo Sync",
                                         prefName);
        }
        if (ignore == "OK") {
            for each (let file in files) {
                this.engine.ignoreTool(file);
            }
            selection.clearSelection();
            return true;
        } else {
            return false;
        }
    }
}

window.addEventListener("load", function(event) { ToolboxSyncController.onLoad(event); }, false);